<template>
  <div class="container mx-auto px-4 py-8 overflow-y-auto">
    <!-- AI Assistant Enable Section -->
    <ScheduleSection 
      :form="form" 
      :weekDays="weekDays" 
      @saveSchedule="saveSchedule" 
    />

    <!-- Classification Agent Section -->
    <ClassificationSection 
      :classificationEnabled="classificationEnabled" 
      @saveClassificationSettings="saveClassificationSettings"
      @openClassificationModal="openClassificationModal"
    />

    <!-- AI Assistant Management -->
    <AssistantManagementSection 
      :assistants="assistants" 
      @openAssistantModal="openAssistantModal"
      @deleteAssistant="deleteAssistant"
    />

    <!-- Assistant Modal -->
    <AssistantModal 
      v-if="showModal" 
      :showModal="showModal"
      :assistantForm="assistantForm"
      :knowledgeBases="knowledgeBases"
      @close="showModal = false"
      @saveAssistant="saveAssistant"
    />

    <!-- Classification Modal -->
    <ClassificationModal 
      v-if="showClassificationModal"
      :showModal="showClassificationModal"
      :classificationForm="classificationForm"
      @close="showClassificationModal = false"
      @saveClassificationSettings="saveClassificationSettings"
    />
  </div>
</template>

<script>
import { ref, onMounted } from 'vue';
import { useForm } from '@inertiajs/vue3';
import ScheduleSection from './ScheduleSection.vue';
import ClassificationSection from './ClassificationSection.vue';
import AssistantManagementSection from './AssistantManagementSection.vue';
import AssistantModal from './AssistantModal.vue';
import ClassificationModal from './ClassificationModal.vue';

export default {
  components: {
    ScheduleSection,
    ClassificationSection,
    AssistantManagementSection,
    AssistantModal,
    ClassificationModal
  },
  
  props: {
    assistants: {
      type: Array,
      default: () => []
    },
    settings: {
      type: Object,
      default: null
    },
    classificationSettings: {
      type: Object,
      default: null
    },
    knowledgeBases: {
      type: Array,
      default: () => []
    }
  },
  
  setup(props) {
    const weekDays = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
    const showModal = ref(false);
    const showClassificationModal = ref(false);
    const classificationEnabled = ref(props.classificationSettings?.enabled ?? false);
    
    // Form for schedule settings
    const form = ref({
      enabled: props.settings?.enabled ?? false,
      selectedDays: props.settings?.selected_days ? JSON.parse(props.settings.selected_days) : [0, 1, 2, 3, 4, 5, 6],
      startTime: props.settings?.start_time ?? '09:00',
      endTime: props.settings?.end_time ?? '17:00',
      use_ai_processing: props.settings?.use_ai_processing ?? false
    });
    
    // Form for assistant settings
    const assistantForm = ref({
      id: null,
      name: '',
      description: '',
      classification_purpose: false,
      enabled: true,
      knowledge_base_id: null,
      settings: JSON.stringify({
        classification: '',
        prePrompt: '',
        maxTokens: 2000,
        temperature: 0.7,
        memoryEnabled: true,
        memorySize: 10
      })
    });
    
    // Form for classification settings
    const classificationForm = ref({
      enabled: props.classificationSettings?.enabled ?? false,
      categories: props.classificationSettings?.settings ? 
        JSON.parse(props.classificationSettings.settings).categories || [] : 
        []
    });
    
    function loadData() {
      // This function could be used to refresh data from the server
      // For now, we're using props
    }
    
    function openAssistantModal(assistant = null) {
      if (assistant) {
        const settings = JSON.parse(assistant.settings);
        assistantForm.value = {
          id: assistant.id,
          name: assistant.name,
          description: assistant.description,
          classification_purpose: assistant.classification_purpose,
          enabled: assistant.enabled,
          knowledge_base_id: assistant.knowledge_base_id,
          settings: JSON.stringify({
            classification: settings.classification || '',
            prePrompt: settings.prePrompt || '',
            maxTokens: settings.maxTokens || 2000,
            temperature: settings.temperature || 0.7,
            memoryEnabled: settings.memoryEnabled || true,
            memorySize: settings.memorySize || 10
          })
        };
      } else {
        assistantForm.value = {
          id: null,
          name: '',
          description: '',
          classification_purpose: false,
          enabled: true,
          knowledge_base_id: null,
          settings: JSON.stringify({
            classification: '',
            prePrompt: '',
            maxTokens: 2000,
            temperature: 0.7,
            memoryEnabled: true,
            memorySize: 10
          })
        };
      }
      showModal.value = true;
    }
    
    function saveAssistant() {
      const formData = useForm(assistantForm.value);
      
      if (assistantForm.value.id) {
        formData.put(`/ai-assistant/${assistantForm.value.id}`, {
          onSuccess: () => {
            showModal.value = false;
            loadData();
          }
        });
      } else {
        formData.post('/ai-assistant', {
          onSuccess: () => {
            showModal.value = false;
            loadData();
          }
        });
      }
    }
    
    function deleteAssistant(id) {
      if (confirm('Are you sure you want to delete this AI Assistant?')) {
        const formData = useForm({});
        formData.delete(`/ai-assistant/${id}`, {
          onSuccess: () => {
            loadData();
          }
        });
      }
    }
    
    function saveSchedule() {
      const formData = useForm({
        enabled: form.value.enabled,
        days: form.value.selectedDays,
        startTime: form.value.startTime,
        endTime: form.value.endTime,
        use_ai_processing: form.value.use_ai_processing
      });
      
      formData.post('/ai-assistant/schedule', {
        onSuccess: () => {
          loadData();
        }
      });
    }
    
    function openClassificationModal() {
      showClassificationModal.value = true;
    }
    
    function saveClassificationSettings() {
      const formData = useForm({
        settings: JSON.stringify({
          enabled: classificationForm.value.enabled,
          categories: classificationForm.value.categories
        })
      });
      
      formData.post('/ai-assistant/classification/settings', {
        onSuccess: () => {
          showClassificationModal.value = false;
          classificationEnabled.value = classificationForm.value.enabled;
          loadData();
        }
      });
    }
    
    onMounted(() => {
      loadData();
    });
    
    return {
      weekDays,
      form,
      assistantForm,
      classificationForm,
      showModal,
      showClassificationModal,
      classificationEnabled,
      openAssistantModal,
      saveAssistant,
      deleteAssistant,
      saveSchedule,
      openClassificationModal,
      saveClassificationSettings
    };
  }
};
</script>
